from typing import Any

def reset(*args, **kwargs) -> Any: ...
def writebyte(*args, **kwargs) -> Any: ...
def writebit(*args, **kwargs) -> Any: ...
def crc8(*args, **kwargs) -> Any: ...
def readbyte(*args, **kwargs) -> Any: ...
def readbit(*args, **kwargs) -> Any: ...
