RC: str
CONFIG: str

def input_choice(prompt, choices): ...
def getpass(prompt): ...
def input_pass(): ...
def exists(fname): ...
def get_daemon_status(): ...
def change_daemon(action) -> None: ...
def main() -> None: ...
